pub struct CsrEdgeId<Index>(pub Index);Expand description
Local edge ID for CsrGraph.
Values are dense handles into the flat CSR target array. They are topology-local IDs and are not stable across sorting, rebuilding, or compaction unless a higher layer defines that contract.
Performance
Copying, comparing, ordering, hashing, and debug-formatting are O(1) when
the underlying index type provides those operations in O(1).
Tuple Fields
0: IndexTrait Implementations
Sourceimpl<Index: Ord> Ord for CsrEdgeId<Index>
impl<Index: Ord> Ord for CsrEdgeId<Index>
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<Index: PartialEq> PartialEq for CsrEdgeId<Index>
impl<Index: PartialEq> PartialEq for CsrEdgeId<Index>
Sourceimpl<Index: PartialOrd> PartialOrd for CsrEdgeId<Index>
impl<Index: PartialOrd> PartialOrd for CsrEdgeId<Index>
impl<Index: Copy> Copy for CsrEdgeId<Index>
impl<Index: Eq> Eq for CsrEdgeId<Index>
impl<Index> StructuralPartialEq for CsrEdgeId<Index>