pub struct CsrNodeId<Index>(pub Index);Expand description
Local node ID for CsrGraph.
Values are dense handles in 0..node_count for one validated CSR view. They
are topology-local IDs and are not stable across rebuilding or compaction
unless a higher layer defines that contract.
Performance
Copying, comparing, ordering, hashing, and debug-formatting are O(1) when
the underlying index type provides those operations in O(1).
Tuple Fields
0: IndexTrait Implementations
Sourceimpl<Index: Ord> Ord for CsrNodeId<Index>
impl<Index: Ord> Ord for CsrNodeId<Index>
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<Index: PartialEq> PartialEq for CsrNodeId<Index>
impl<Index: PartialEq> PartialEq for CsrNodeId<Index>
Sourceimpl<Index: PartialOrd> PartialOrd for CsrNodeId<Index>
impl<Index: PartialOrd> PartialOrd for CsrNodeId<Index>
impl<Index: Copy> Copy for CsrNodeId<Index>
impl<Index: Eq> Eq for CsrNodeId<Index>
impl<Index> StructuralPartialEq for CsrNodeId<Index>